#[non_exhaustive]pub enum DaemonError {
Protocol(ParseError),
Store(StoreError),
Engine(EngineError),
Io(Error),
Other(Error),
StaleToken {
current: StateToken,
reason: &'static str,
},
NoSession,
UnknownSession(String),
UnknownPage(String),
UnknownRef(u32),
BadRequest(String),
Unsupported {
engine: &'static str,
primitive: &'static str,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Protocol(ParseError)
Store(StoreError)
Engine(EngineError)
Io(Error)
Other(Error)
StaleToken
The agent’s pre-image token did not match the page’s current token.
NoSession
No active session for this connection.
UnknownSession(String)
Session id refers to no known session.
UnknownPage(String)
Page id refers to no known page in this session.
UnknownRef(u32)
Ref does not exist in the page’s current tree.
BadRequest(String)
The wire request was malformed.
Unsupported
Engine’s capability set excludes this primitive on this platform.
Implementations