serve

Function serve 

pub async fn serve(
    daemon: Daemon,
    path: impl AsRef<Path>,
    shutdown: Receiver<()>,
) -> Result<()>
Bind a local socket at path and serve daemon on it. On Unix path is the AF_UNIX socket file; on Windows it’s used to derive a stable namespaced pipe name (see crate::transport::path_to_name). Loops until shutdown resolves.